[![Documentation Status](https://readthedocs.org/projects/waterentropy/badge/?version=latest)](https://waterentropy.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/jkalayan/waterEntropy/badge.svg?branch=main)](https://coveralls.io/github/jkalayan/waterEntropy?branch=main)

# waterEntropy
The Python package for calculating interfacial water entropy from molecular dynamics simulations.

<p align="center">
<img src="docs/source/images/waterentropy_logo_grey.png" width="500px" />
</p>

## Documentation

See [here](https://waterentropy.readthedocs.io/en/latest/) for documentation for users and developers.

## License

MIT

## Contact

- jas.kalayan@stfc.ac.uk
